@warn "This import is deprecated. Use 'compass/typography/lists' instead.";

@import "../typography/lists/horizontal-list";
@import "../typography/lists/inline-list";
@import "../typography/lists/inline-block-list";
@import "../typography/lists/bullets";
