@warn "This import is deprecated. Use 'compass/typography/links' instead.";

@import "../typography/links/hover-link";
@import "../typography/links/link-colors";
@import "../typography/links/unstyled-link";
